(***********************************************************************)
(*                                                                     *)
(*                               TAToo                                 *)
(*                                                                     *)
(*                     Kim Nguyen, LRI UMR8623                         *)
(*                   Université Paris-Sud & CNRS                       *)
(*                                                                     *)
(*  Copyright 2010-2012 Université Paris-Sud and Centre National de la *)
(*  Recherche Scientifique. All rights reserved.  This file is         *)
(*  distributed under the terms of the GNU Lesser General Public       *)
(*  License, with the special exception on linking described in file   *)
(*  ../LICENSE.                                                        *)
(*                                                                     *)
(***********************************************************************)

(** Implementation of qualified names as hashconsed strings *)

include Hcons.S with type data = string
include Common_sig.Printable with type t := t


val of_string : string -> t
(** Utility function, equivalent to [make] *)

val to_string : t -> string
(** Utility function, equivalent to [node] *)


(** Special constants, that denote the QName of nodes that are not
    elements (using the nodeValue property of DOM for such nodes.
*)

val document : t
(** Represents the QName of a document node. Equivalent to
    [of_string "#document"]
*)

val text : t
(** Represents the QName of a text node. Equivalent to
    [of_string "#text"]
*)

val comment : t
(** Represents the QName of a comment node. Equivalent to
    [of_string "#comment"]
*)

val nil : t
(** Represents the QName of a nil node. Equivalent to
    [of_string "#"]
*)
(*
val attribute : t -> t
(** Adds a prefix character (@) to distinguish the name
    from an element name
*)

val processing_instruction : t -> t
(** Adds a prefix character (?) to distinguish the name
    from an element name
*)

val remove_prefix : t -> t
(** Removes the prefix of the qname given as argument. Does not
    do anything if there is no prefix.
*)
*)
